@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import os, os.path as op, sys
+from datetime import date
 
 from opster import Dispatcher
 from termcolor import cprint, colored
@@ -10,7 +11,7 @@ from nomad.engine import DBError
 from nomad.utils import abort, NomadError, NomadIniNotFound
 
 
-__version__ = '1.7'
+__version__ = '1.8'
 
 
 GLOBAL = [
@@ -77,14 +78,15 @@ def list_(all=('a', False, 'show all migrations (default: only non-applied)'),
 @app.command()
 def create(name,
            dependencies=('d', [], 'migration dependencies'),
+           prefix_date=('p', False, 'prefix migration name with date'),
            **opts):
     '''Create new migration
     '''
     repo = opts['repo']
-    try:
-        deps = map(repo.get, dependencies)
-    except NomadError, e:
-        abort(e)
+    deps = map(repo.get, dependencies)
+
+    if prefix_date:
+        name = date.today().strftime('%Y%m%d-') + name
 
     path = op.join(repo.path, name)
     try:
@@ -136,7 +138,10 @@ def apply(all=('a', False, 'apply all available migrations'),
             abort('migration %s is already applied' % m)
     for m in migrations:
         if not m.applied:
-            m.apply(env=env)
+            try:
+                m.apply(env=env)
+            except DBError, e:
+                abort('cannot apply migration %s: %s' % (m, e))
 
 
 @app.command()
@@ -155,7 +160,7 @@ def info(**opts):
 
 @app.command()
 def version(**opts):
-    '''Show app version
+    '''Show nomad version
     '''
     print 'Nomad v%s' % __version__
 
