@@ -6,6 +6,7 @@ from functools import wraps
 
 from nomad.utils import (cachedproperty, geturl, NomadError, NomadIniNotFound,
                          clean_sql, abort, humankey)
+from nomad.engine import DBError
 
 
 def tx(getrepo):
@@ -106,7 +107,9 @@ class Migration(object):
         self.repo = repo
         self.name = name
         if not op.exists(op.join(repo.path, name)) and not force:
-            raise NomadError('migration not found: %s' % name)
+            raise NomadError(
+                'migration exists in database, but not found on the disk: %s'
+                % name)
         self.conf = ConfigParser(
             interpolation=ExtendedInterpolation(),
             defaults={
@@ -145,11 +148,13 @@ class Migration(object):
                 dep.apply()
 
         print 'applying migration %s:' % self
+        filenames = sorted(os.listdir(self.path), key=humankey)
 
-        for fn in sorted(os.listdir(self.path), key=humankey):
+        for fn in filenames:
             if fn == 'migration.ini':
                 continue
             path = op.join(self.path, fn)
+
             if fn.endswith('.sql'):
                 with open(path) as f:
                     self.repo.engine.query(clean_sql(f.read()))
@@ -158,7 +163,9 @@ class Migration(object):
                 callenv = dict(os.environ, NOMAD_DBURL=self.repo.url)
                 if env:
                     callenv.update(env)
-                call(path, env=callenv)
+                retcode = call(path, env=callenv)
+                if retcode:
+                    raise DBError('script failed: %s' % fn)
                 print '  script migration applied: %s' % fn
             else:
                 print '  skipping file: %s' % fn
